@@ -10,8 +10,9 @@ def Connection(config: Config):
     try:
         yield repository
         repository.commit()
+        # repository.session.flush()
     except Exception as e:
-        Log.error('Error while running database operation: {e}')
+        Log.error(f'Error while running database operation: {e}')
         repository.rollback()
         raise Exception()
     finally:
