@@ -62,6 +62,15 @@ class Parser:
     def switch_to(self, element: any) -> None:
         self.scraper.switch_to(element=element)
 
+    def freeze(self) -> None:
+        self.scraper.freeze()
+
+    def unfreeze(self) -> None:
+        self.scraper.unfreeze()
+
+    def close(self) -> None:
+        self.scraper.close()
+
     #endregion methods
 
     def get_scraper(self, config: Config, user_dir: str=None, headless: bool=True, window: dict={}) -> Scraper:
