@@ -268,5 +268,11 @@ class Selenium(Scraper):
     def on_switch_to(self, element: any) -> None:
         self.driver.switch_to.frame(element)
 
+    def on_freeze(self) -> None:
+        self.driver.execute_cdp_cmd('Emulation.setScriptExecutionDisabled', { 'value': True })
+
+    def on_unfreeze(self) -> None:
+        self.driver.execute_cdp_cmd('Emulation.setScriptExecutionDisabled', { 'value': False })
+
     def on_close(self):
         self.driver.quit()
\ No newline at end of file
